@@ -1,6 +1,8 @@
-use v5.36;
+use warnings;
+use strict;
 use lib 'lib';
 use App::Games::Keno;
+use feature 'say';
 
 my $first_game = App::Games::Keno->new( num_spots => 5, draws => 1000 );
 $first_game->PlayKeno;
@@ -10,7 +12,7 @@ say "You won \$"
   . " draws.";
 
 my $second_game = App::Games::Keno->new(
-	spots => [ 45, 33, 12, 20, 75 ],
+	spots => [ 45, 33, 12, 20 ],
 	draws => 1000
 );
 $second_game->PlayKeno;
